==> plone.stringinterp-1.3.0.tar.gz: plone.stringinterp-1.3.0/setup.py <==
from setuptools import setup, find_packages

version = '1.3.0'

setup(
    name='plone.stringinterp',
    version=version,
    description="Adaptable string interpolation",
    long_description=(open("README.rst").read() + "\n" +
                      open("CHANGES.rst").read()),
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 5.0",
        "Framework :: Plone :: 5.1",
        "Framework :: Plone :: 5.2",
        "Framework :: Zope2",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    keywords='Plone Zope Interpolation',
    author='Plone Foundation',
    author_email='plone-developers@lists.sourceforge.net',
    url='https://pypi.python.org/pypi/plone.stringinterp',
    license='GPL version 2',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['plone'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'Products.CMFCore',
        'zope.i18n',
        'plone.memoize',
    ],
    extras_require={
        'test': [
            'plone.app.contenttypes',
            'plone.app.testing',
            'plone.testing',
        ],
    },
    entry_points="""
        [z3c.autoinclude.plugin]
        target = plone
    """,
)

==> plone.stringinterp-1.3.2.tar.gz: plone.stringinterp-1.3.2/setup.py <==
from setuptools import setup, find_packages

version = '1.3.2'

setup(
    name='plone.stringinterp',
    version=version,
    description="Adaptable string interpolation",
    long_description=(open("README.rst").read() + "\n" +
                      open("CHANGES.rst").read()),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 5.0",
        "Framework :: Plone :: 5.1",
        "Framework :: Plone :: 5.2",
        "Framework :: Plone :: Core",
        "Framework :: Zope2",
        "Framework :: Zope :: 4",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    keywords='Plone Zope Interpolation',
    author='Plone Foundation',
    author_email='plone-developers@lists.sourceforge.net',
    url='https://pypi.org/project/plone.stringinterp',
    license='GPL version 2',
    packages=find_packages(),
    namespace_packages=['plone'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'Products.CMFCore',
        'zope.i18n',
        'plone.memoize',
    ],
    extras_require={
        'test': [
            'plone.app.contenttypes',
            'plone.app.testing',
            'plone.testing',
        ],
    },
    entry_points="""
        [z3c.autoinclude.plugin]
        target = plone
    """,
)
